encode_mesh

Function encode_mesh 

pub fn encode_mesh<W>(
    mesh: Mesh,
    writer: &mut W,
    cfg: Config,
) -> Result<(), Err>
where W: ByteWriter,
Encodes the input mesh into a provided byte stream using the provided configuration, with a freshly constructed Encoder.