encode_point_cloud

Function encode_point_cloud 

pub fn encode_point_cloud<W>(
    pc: PointCloud,
    writer: &mut W,
    cfg: PointCloudConfig,
) -> Result<(), Err>
where W: ByteWriter,
Encodes the input point cloud into a provided byte stream using the provided configuration, with a freshly constructed Encoder.