pub struct Encoder {}Expand description
The mesh encoder. A single instance is meant to be reused across encodes so it can share resources between runs.
Implementations
Sourceimpl Encoder
impl Encoder
Sourcepub fn encode_mesh<W>(
&mut self,
mesh: Mesh,
writer: &mut W,
cfg: Config,
) -> Result<(), Err>where
W: ByteWriter,
pub fn encode_mesh<W>(
&mut self,
mesh: Mesh,
writer: &mut W,
cfg: Config,
) -> Result<(), Err>where
W: ByteWriter,
Encodes the input mesh into a provided byte stream using the provided configuration.
Sourcepub fn encode_point_cloud<W>(
&mut self,
pc: PointCloud,
writer: &mut W,
cfg: PointCloudConfig,
) -> Result<(), Err>where
W: ByteWriter,
pub fn encode_point_cloud<W>(
&mut self,
pc: PointCloud,
writer: &mut W,
cfg: PointCloudConfig,
) -> Result<(), Err>where
W: ByteWriter,
Encodes the input point cloud into a provided byte stream using the provided configuration.