Mesh

Struct Mesh 

pub struct Mesh {
    pub faces: Vec<[PointIdx; 3]>,
    pub attributes: Vec<Attribute>,
    /* private fields */
}
The geometry container consumed by encode, and the builder used to assemble one.

Everything needed to drive the encoder is reachable from draco_oxide alone:

use draco_oxide::{
    Attribute, AttributeDomain, AttributeType, ComponentDataType, ConfigType, Mesh,
    MeshBuilder, NdVector,
};
use draco_oxide::encode::Config;

let _builder = MeshBuilder::new();
let _cfg = <Config as ConfigType>::default();
let _ty = AttributeType::Position;
let _dom = AttributeDomain::Position;
let _ct = ComponentDataType::F32;
fn _drives(_m: Mesh, _a: Attribute, _v: NdVector<3, f32>) {}

Represents a 3D mesh. It consists of a list of faces, where each face is defined by three vertex indices, and a list of attributes (Attribute) that can be associated with the mesh.

Fields

faces: Vec<[PointIdx; 3]>attributes: Vec<Attribute>

Implementations

Source

impl Mesh

pub fn get_attributes(&self) -> &[Attribute]

pub fn get_faces(&self) -> &[[PointIdx; 3]]

pub fn get_attributes_mut(&mut self) -> &mut [Attribute]

pub fn get_attributes_mut_by_indices<'a>( &'a mut self, indices: &[usize], ) -> Vec<&'a mut Attribute>

pub fn get_name(&self) -> &str

pub fn set_name(&mut self, name: &str)

pub fn new() -> Mesh

pub fn diff_l2_norm(&self, other: &Mesh) -> f64