pub struct MeshBuilder {
pub attributes: Vec<Attribute>,
/* private fields */
}Expand description
The geometry container consumed by encode, and the builder
used to assemble one.
Everything needed to drive the encoder is reachable from draco_oxide alone:
use draco_oxide::{
Attribute, AttributeDomain, AttributeType, ComponentDataType, ConfigType, Mesh,
MeshBuilder, NdVector,
};
use draco_oxide::encode::Config;
let _builder = MeshBuilder::new();
let _cfg = <Config as ConfigType>::default();
let _ty = AttributeType::Position;
let _dom = AttributeDomain::Position;
let _ct = ComponentDataType::F32;
fn _drives(_m: Mesh, _a: Attribute, _v: NdVector<3, f32>) {}Fields
attributes: Vec<Attribute>Implementations
Sourceimpl MeshBuilder
impl MeshBuilder
pub fn new() -> MeshBuilder
pub fn add_attribute<Data, const N: usize>(
&mut self,
data: Vec<Data>,
att_type: AttributeType,
domain: AttributeDomain,
parents: Vec<AttributeId>,
) -> AttributeIdwhere
Data: Vector<N>,
pub fn add_empty_attribute( &mut self, att_type: AttributeType, domain: AttributeDomain, component_type: ComponentDataType, num_component: usize, ) -> AttributeId
pub fn set_connectivity_attribute(&mut self, data: Vec<[usize; 3]>)
pub fn build(self) -> Result<Mesh, Err>